pub async fn list_op(
transport: &Transport,
filter: &DashboardFilter,
) -> Result<DashboardList>Expand description
Page through dashboard summaries, apply filters, and sort by stable id.
pub async fn list_op(
transport: &Transport,
filter: &DashboardFilter,
) -> Result<DashboardList>Page through dashboard summaries, apply filters, and sort by stable id.