pub fn plan_bundle_import(
path: &Path,
overwrite: bool,
) -> Result<BundleImportPlan>Expand description
Fully read and scan an opaque bundle before presenting its mutation guard.
pub fn plan_bundle_import(
path: &Path,
overwrite: bool,
) -> Result<BundleImportPlan>Fully read and scan an opaque bundle before presenting its mutation guard.