pub async fn resolve(
transport: &Transport,
selector: &str,
) -> Result<DashboardSummary>Expand description
Resolve a dashboard by exact id, then by exact title only after an id miss.
pub async fn resolve(
transport: &Transport,
selector: &str,
) -> Result<DashboardSummary>Resolve a dashboard by exact id, then by exact title only after an id miss.