pub async fn create(
transport: &Transport,
spec: &DataViewSpec,
) -> Result<DataView>Expand description
Create a data view with its explicit, portable id.
pub async fn create(
transport: &Transport,
spec: &DataViewSpec,
) -> Result<DataView>Create a data view with its explicit, portable id.