pub async fn apply_default(
transport: &Transport,
plan: &DefaultPlan,
) -> Result<()>Expand description
Apply a guarded default change after checking the observed default remains the exact snapshot shown to the operator.
pub async fn apply_default(
transport: &Transport,
plan: &DefaultPlan,
) -> Result<()>Apply a guarded default change after checking the observed default remains the exact snapshot shown to the operator.