pub async fn list_op(
transport: &Transport,
filter: &DataViewFilter,
) -> Result<DataViewList>Expand description
List data views using the portable command filter and stable-id ordering.
pub async fn list_op(
transport: &Transport,
filter: &DataViewFilter,
) -> Result<DataViewList>List data views using the portable command filter and stable-id ordering.