pub async fn resolve(
transport: &Transport,
selector: &str,
) -> Result<DataViewSummary>Expand description
Resolve one selector over the wire with one data-view list read.
pub async fn resolve(
transport: &Transport,
selector: &str,
) -> Result<DataViewSummary>Resolve one selector over the wire with one data-view list read.