pub async fn create(
transport: &Transport,
spec: &AgentPolicySpec,
) -> Result<AgentPolicy>Expand description
Create a policy with its explicit id and no implicit System integration.
pub async fn create(
transport: &Transport,
spec: &AgentPolicySpec,
) -> Result<AgentPolicy>Create a policy with its explicit id and no implicit System integration.