pub async fn export(
transport: &Transport,
selectors: &[String],
all_custom: bool,
format: ContentFormat,
) -> Result<ExportOutcome>Expand description
Export selected policies, or every custom policy, as a portable artifact.
pub async fn export(
transport: &Transport,
selectors: &[String],
all_custom: bool,
format: ContentFormat,
) -> Result<ExportOutcome>Export selected policies, or every custom policy, as a portable artifact.