pub struct ExportSummary {
pub exported_count: u64,
pub exported_rules_count: u64,
pub missing_rules_count: u64,
pub missing_rules: Vec<Value>,
}Expand description
The trailer Kibana appends to an NDJSON export. It is the entire body for a zero-rule export, so it must not be parsed as a rule.
Fields
exported_count: u64exported_rules_count: u64missing_rules_count: u64missing_rules: Vec<Value>Rules selected for export but not returned, likely deleted after selection. Kept as raw server values.