Change evidence for a push attached to a change ticket.
Records the proposed and applied changes, with values on both sides.
Change evidence for a push attached to a change ticket.
Records the proposed and applied changes, with values on both sides.