preview

Function preview 

pub async fn preview(
    t: &Transport,
    rule: &Rule,
    invocation_count: u32,
    timeframe_end: &str,
) -> Result<PreviewResult>
Run a rule against historical data without writing alerts.

The API requires invocationCount and timeframeEnd. The logs array has errors and warnings for each simulated invocation.