pub struct DanglingPointer {
pub rule_id: String,
pub list_id: String,
pub stored_id: Value,
pub live_id: Option<String>,
}Expand description
A rule whose stored exception pointer does not match the live container.
live_id is None when no container with that list_id exists on this
stack.
Fields
rule_id: Stringlist_id: Stringstored_id: Valuelive_id: Option<String>Trait Implementations
Sourceimpl Clone for DanglingPointer
impl Clone for DanglingPointer
Sourcefn clone(&self) -> DanglingPointer
fn clone(&self) -> DanglingPointer
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DanglingPointer
impl Debug for DanglingPointer
Sourceimpl PartialEq for DanglingPointer
impl PartialEq for DanglingPointer
Sourceimpl Serialize for DanglingPointer
impl Serialize for DanglingPointer
impl StructuralPartialEq for DanglingPointer